@@ -21,10 +21,11 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+import locale
 from optparse import OptionParser
 import os
-import sys
 
+from timebook import get_version
 from timebook.db import Database
 from timebook.commands import commands, run_command
 from timebook.config import parse_config
@@ -33,7 +34,7 @@ from timebook.cmdutil import AmbiguousLookup, NoMatch
 confdir = os.path.expanduser(os.path.join('~', '.config', 'timebook'))
 DEFAULTS = {'config': os.path.join(confdir, 'timebook.ini'),
             'timebook': os.path.join(confdir, 'sheets.db'),
-            'encoding': sys.stdin.encoding}
+            'encoding': locale.getpreferredencoding()}
 
 def parse_options():
     cmd_descs = ['%s - %s' % (k, commands[k].description) for k
@@ -42,26 +43,30 @@ def parse_options():
 [ARGS...]
 
 where COMMAND is one of:
-    %s''' % '\n    '.join(cmd_descs))
+    %s''' % '\n    '.join(cmd_descs), version=get_version())
     parser.disable_interspersed_args()
     parser.add_option('-C', '--config', dest='config',
                       default=DEFAULTS['config'], help='Specify an \
-alternate configuration file (default: %r).' % DEFAULTS['config'])
+alternate configuration file (default: "%s").' % DEFAULTS['config'])
     parser.add_option('-b', '--timebook', dest='timebook',
                       default=DEFAULTS['timebook'], help='Specify an \
-alternate timebook file (default: %r).' % DEFAULTS['timebook'])
+alternate timebook file (default: "%s").' % DEFAULTS['timebook'])
     parser.add_option('-e', '--encoding', dest='encoding',
                       default=DEFAULTS['encoding'], help='Specify an \
 alternate encoding to decode command line options and arguments (default: \
-%r)' % DEFAULTS['encoding'])
+"%s")' % DEFAULTS['encoding'])
     options, args = parser.parse_args()
     encoding = options.__dict__.pop('encoding')
-    options.__dict__ = dict((k, v.decode(encoding)) for (k, v) in
-                            options.__dict__.iteritems())
-    args = [a.decode(encoding) for a in args]
+    try:
+        options.__dict__ = dict((k, v.decode(encoding)) for (k, v) in
+                                options.__dict__.iteritems())
+        args = [a.decode(encoding) for a in args]
+    except LookupError:
+        parser.error('unknown encoding %s' % encoding)
 
     if len(args) < 1:
-        parser.error('no command specified')
+        # default to ``t now``
+        args = ['now'] + args
     return options, args
 
 def run_from_cmdline():
